@@ -4,10 +4,10 @@ from pyal.list.linked_list import LinkedList, ListNode
 def test_list():
   list = LinkedList()
   list.push_front(1)
-  assert list.begin()() == 1
+  assert list.begin().get() == 1
 
   list.push_back(2)
-  assert list.rbegin()() == 2
+  assert list.rbegin().get() == 2
 
   assert list.size() == 2
   assert list.to_list() == [1, 2]
@@ -29,7 +29,7 @@ def test_insertion():
   data = []
   iter = list.begin()
   while iter is not list.end():
-    data.append(iter())
+    data.append(iter.get())
     iter = iter.next()
 
   assert data == [0, 2, 3, 100, 4]
@@ -37,7 +37,7 @@ def test_insertion():
   data = []
   iter = list.rbegin()
   while iter is not list.rend():
-    data.append(iter())
+    data.append(iter.get())
     iter = iter.prev()
 
   assert data == [0, 2, 3, 100, 4][::-1]
